use serde::{Deserialize, Serialize};

#[derive(Debug, Serialize, Deserialize)]
pub struct Config {
    #[serde(default)]
    pub build_by_default: bool,
}

impl Default for Config {
    fn default() -> Config {
        Config {
            build_by_default: false,
        }
    }
}

impl Config {
    pub fn from_path(path: &str) -> Result<Config, String> {
        match std::fs::read_to_string(path) {
            Ok(s) => match toml::from_str(&s) {
                Ok(c) => Ok(c),
                Err(e) => Err(format!("failed to parse config: {}", e)),
            },
            Err(e) => Err(format!("failed to read config: {}", e)),
        }
    }
}
